from urllib.parse import urlparse

import requests


class ArthurOIDCMetadata:
    def __init__(self, arthur_host: str):
        self.arthur_host = ArthurOIDCMetadata.extract_host(arthur_host)
        self.metadata = None

    @staticmethod
    def extract_host(arthur_host: str) -> str:
        parsed = urlparse(arthur_host, scheme="https")
        if not parsed.netloc:
            raise ValueError("Bad Arthur host configuration, hostname not found")
        return parsed.scheme + "://" + parsed.netloc

    def _well_known_endpoint(self) -> str:
        return (
            self.arthur_host.rstrip("/")
            + "/api/v1/auth/oidc/.well-known/openid-configuration"
        )

    def _fetch_metadata(self) -> None:
        resp = requests.get(self._well_known_endpoint())
        self.metadata = resp.json()

    @property
    def token_endpoint(self) -> str:
        if self.metadata is None:
            self._fetch_metadata()

        return self.metadata["token_endpoint"]

    @property
    def device_authorization_endpoint(self) -> str:
        if self.metadata is None:
            self._fetch_metadata()

        return self.metadata["device_authorization_endpoint"]



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.connectors_v1_api import ConnectorsV1Api


class TestConnectorsV1Api(unittest.TestCase):
    """ConnectorsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = ConnectorsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_connector(self) -> None:
        """Test case for delete_connector

        Delete Connector
        """
        pass

    def test_get_connector(self) -> None:
        """Test case for get_connector

        Get Connector
        """
        pass

    def test_get_connectors(self) -> None:
        """Test case for get_connectors

        List Connectors
        """
        pass

    def test_get_sensitive_connector(self) -> None:
        """Test case for get_sensitive_connector

        Get Sensitive Connector
        """
        pass

    def test_patch_connector(self) -> None:
        """Test case for patch_connector

        Update Connector
        """
        pass

    def test_post_connector(self) -> None:
        """Test case for post_connector

        Create Connector
        """
        pass

    def test_put_connector_check_results(self) -> None:
        """Test case for put_connector_check_results

        Persist Connector Check Results
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DataResultFilterOp(str, Enum):
    """
    DataResultFilterOp
    """

    """
    allowed enum values
    """
    GREATER_THAN = 'greater_than'
    LESS_THAN = 'less_than'
    EQUALS = 'equals'
    NOT_EQUALS = 'not_equals'
    GREATER_THAN_OR_EQUAL = 'greater_than_or_equal'
    LESS_THAN_OR_EQUAL = 'less_than_or_equal'
    IN = 'in'
    NOT_IN = 'not_in'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DataResultFilterOp from a JSON string"""
        return cls(json.loads(json_str))


